Documentation
¶
Index ¶
Constants ¶
const ( DOWNLOAD_PATHS = "download_paths" UPLOAD_PATHS = "upload_paths" MD5_FILE_MAP = "md5_file_map" )
Variables ¶
This section is empty.
Functions ¶
func CacheFileMD5Map ¶ added in v0.0.6
func CacheFileMD5Map()
func SyncFolder ¶
func SyncFolder() error
SyncFolder synchronizes the source folder with the target folder in the BaiduDisk cloud storage.
It retrieves the cloud file list, compares it with the local files in the source folder, and performs the following operations: - Uploads the files that are not present in the cloud storage. - Downloads the files that are present in the cloud storage but missing locally.
The function takes no parameters and returns an error if any occurs during the synchronization process.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.